#
# spec file for package cloud-regionsrv
# this code base is under development
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           cloud-regionsrv
Version:        8.1.2
Release:        11.6.1
License:        GPL-3.0+
Summary:        Cloud Environment Region Service
URL:            https://github.com/SUSE-Enceladus/cloud-regionsrv
Group:          Productivity/Networking/Web/Servers
Source0:        %{name}-%{version}.tar.bz2
Requires:       apache2
Requires:       apache2-mod_wsgi-python3     >= 4.2.8
Requires:       openssl
Requires:       python3
Requires:       python3-Flask
Requires:       python3-pyOpenSSL
Requires:       python3-pytricia
Requires:       cloud-region-config
Requires(pre):  pwdutils
Recommends:     cspApacheAccessConfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

BuildArch:      noarch

%description
Cloud region resolver service, returns SMT server information
for the region based on the client IP address.

%package generic-config
Version:      1.0.0
License:      GPL-3.0+
Summary:      Cloud Environment Region Service Configuration
Group:        Productivity/Networking/Web/Servers
Provides:     cloud-region-config
Conflicts:    otherproviders(cloud-region-config)

%description generic-config
Generic configuration for the region service

%prep
%setup -q

%build

%install
%make_install

%pre
if ! grep -q regionsrv /etc/group; then
    /usr/sbin/groupadd --system regionsrv  2> /dev/null
fi
if ! grep -q regionsrv /etc/passwd; then
    /usr/sbin/useradd -r -g regionsrv -s /bin/false -c "Cloud Region Service" \
        -d /var/lib/regionsrv regionsrv 2> /dev/null || :
else
    /usr/sbin/usermod -g regionsrv -G regionsrv -s /bin/false regionsrv \
      2> /dev/null
fi

%files
%defattr(-,root,root,-)
%doc LICENSE README.md
%config(noreplace) %{_sysconfdir}/apache2/vhosts.d/regionsrv_vhost.conf
%config %{_sysconfdir}/logrotate.d/regionInfo.lr
%attr(755,regionsrv,regionsrv) %dir /srv/www/regionService
/srv/www/regionService/regionInfo.wsgi
/srv/www/regionService/regionInfo.py
/srv/www/regionService/region_srv.py
%attr(755,regionsrv,regionsrv) %dir /var/log/regionService
%attr(644,regionsrv,regionsrv) %ghost /var/log/regionService/regionInfo.log
%dir %{_sysconfdir}/apache2
%dir %{_sysconfdir}/apache2/vhosts.d
%dir %{_sysconfdir}/regionService
/usr/sbin/genRegionServerCert

%files generic-config
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/regionService/regionData.cfg
%config(noreplace) %{_sysconfdir}/regionService/regionInfo.cfg


%changelog
* Fri Oct  1 2021 jmason@suse.com
- Update to version 8.1.2 (bsc#1190250)
  + Place certificate key in proper destination
* Tue Sep 14 2021 jmason@suse.com
- Update to version 8.1.1 (bsc#1190250)
  + Use a cross-filesystem compatible method to move certificates
* Tue Jun 15 2021 jmason@suse.com
- Update to version 8.1.0 (bsc#1029162)
  + Enable multiple IP assignments (IPv4+IPv6) on TLS Certificate
* Sun Feb 28 2021 rjschwei@suse.com
- Update to version 8.0.5 (bsc#1029162)
  + Improve region hint matching by forcing config settings and
    received regionHint to lower case
  + IPv6 support
  + Remove find_all_matching_cidr.patch home grown matcher removed
* Tue May  5 2020 rjschwei@suse.com
- Add find_all_matching_cidr.patch (bsc#1171232, bsc#1171233)
  + The prefix length matcher returned only the first cidr that was a
    possible match. In the final check that verifies that the requesters
    IP is in the range this might lead to a mismatch and thus a 404.
* Thu Feb  8 2018 rjschwei@suse.com
- Update to version 8.0.1
  + Reduce memory footprint of running application
* Tue Feb  6 2018 rjschwei@suse.com
- Update to version 8.0.0 (bsc#1079233)
  + Port to Python 3
  + Set subjevtAltName when generating a cert
* Thu Nov 17 2016 rjschwei@suse.com
- Include in SLE 12 (FATE#320818, bsc#979331)
* Wed May 18 2016 rjschwei@suse.com
- Update to version 7.0.1
  + Fix argument parsing initialization in cert generator
* Tue May  3 2016 rjschwei@suse.com
- Update to version 7.0.0 - Include in SLE 12 FATE#320818
  + Increase key length to 2048
  + Code clean up, pep8 compliance
  + Upstream source location change to GitHub repo
  + Licensed GPLv3+
* Fri Jan 30 2015 rjschwei@suse.com
- Update to version 6.0.2
  + modified config to accomodate changes in mod_wsgi
  + generalized script to generate the cert
* Thu Oct  9 2014 rschweikert@suse.com
- Update to version 6.0.0
  + accept a region hint from the client
    ~ the client can now provide a location hint by adding ?regionHint=
    to the URL. The server will first try to find a match using the IP
    address of the client and then fall back to the regionHint if it was
    provided. The caveat is that the client has to know the region names
    as they are configured in the regionData.cfg file. However, the region
    names are always well known for each cloud provider.
  + randomize the provided SMT information
    ~ to avoid always handing out the first listed SMT server in the
    configfile and thus loading this server with all requests, the order is
    now randomized.
* Tue Sep  2 2014 rschweikert@suse.com
- Update to version 5.0.0
  + support multiple SMT servers per region
  + this is an incompatible change and breaks existing clients
* Sat May 17 2014 rschweikert@suse.com
- Update to version 4.1.2
  + create the regionsrv user, this was previously deleted accidentally
  + handle exception if the IP range is not properly formed for some
    reason
* Tue Apr 22 2014 rschweikert@suse.com
- update to version 4.1.1
  + create a separate package for the configuration
  - this allows us to create packages for each cloud that just
    carry the configuration
  - provides a single point of update for the configuration for each cloud
  + let the cert generation code also update the ApacheAccessConfig
    service configuration file if it exists
* Mon Apr 14 2014 rschweikert@suse.com
- update to version 4.0.0
  + removed automatic update feature, this is now handled by
    cspApacheAccessConfig
  >>>>>>> ./cloud-regionsrv.changes.r12
* Wed Mar 19 2014 rschweikert@suse.com
- bump to version 3.0.3
  + fixed Makefile to address naming inconsistency of log directory
* Fri Feb 28 2014 rschweikert@suse.com
- fix inconsistency between package and default configuration
  + package created /var/log/regionsrv and configuration expected
    /var/log/regionService. Fxed package to match configureation
* Thu Feb 20 2014 rschweikert@suse.com
- add dependency to pyOpenSSL
* Wed Jan 22 2014 rschweikert@suse.com
- update to version 3.0.0
  - switch the service to be https
    + the previous implementation via http was vulnerable to the traffic
    being intercepted and then having the client register against a
    "fake" SMT server for potential malicious package distribution
  - add a script to create a self signed certificate
  - move the configuration files to regionService directory in etc
  - name consistency updates
* Tue Dec  3 2013 rschweikert@suse.com
- update to version 2.1.0
  + fix call error
* Tue Dec  3 2013 rschweikert@suse.com
- update to version 2.0
  + new data field in the regionData.cfg (smt-server-name)
  + renamed smt-server to smt-sever-ip
  + these are incompatible changes
* Wed Nov 27 2013 rschweikert@suse.com
- merge the %%pre scripts, only one allowed, duh
* Wed Nov 27 2013 rschweikert@suse.com
- update to version 1.1.1:
  - fix the comparison of the digest for the vhost config file
    + compare the digest not the objects duh
  - fix spec file to properly dal with differences between systemd and
    sysv init and systemd location differences
- use all macros required for proper systemd integration
- set the package to noarch
* Mon Nov 25 2013 rschweikert@suse.com
  update to version 1.1.0:
  - modify the region service
    + does not run as root, thus it cannot update the apache configuration
  - implement new service to monitor if the apache configuration needs updating
  - add unit file/sysV init file for the new service
  - update the Makefile to reflect new directory structure
* Mon Nov 25 2013 rschweikert@suse.com
- fix the requires to handle all distros
* Mon Nov 25 2013 rschweikert@suse.com
- add shadow as build requires, supplies user and group commands
  + fixes build failure on 12.3
- modify syntax of %%pre scriptlet to make it a bit easier to understand
* Mon Nov 25 2013 rschweikert@suse.com
- Initial build
